audeer
======

.. automodule:: audeer

.. autosummary::
    :toctree:
    :nosignatures:

    basename_wo_ext
    common_directory
    config
    create_archive
    deprecated
    deprecated_default_value
    deprecated_keyword_argument
    download_url
    extract_archive
    extract_archives
    file_extension
    flatten_list
    format_display_message
    freeze_requirements
    git_repo_tags
    git_repo_version
    install_package
    is_semantic_version
    is_uid
    list_dir_names
    list_file_names
    LooseVersion
    md5
    mkdir
    move_file
    path
    progress_bar
    replace_file_extension
    rmdir
    run_tasks
    safe_path
    sort_versions
    StrictVersion
    to_list
    touch
    uid
